#[non_exhaustive]pub enum CreateFileSystemError {
ConflictException(ConflictException),
InternalServerException(InternalServerException),
ResourceNotFoundException(ResourceNotFoundException),
ServiceQuotaExceededException(ServiceQuotaExceededException),
ValidationException(ValidationException),
ThrottlingException(ThrottlingException),
Unhandled(Unhandled),
}Expand description
Error type for the CreateFileSystemError operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
ConflictException(ConflictException)
The request conflicts with the current state of the resource. This can occur when trying to create a resource that already exists or delete a resource that is in use.
InternalServerException(InternalServerException)
An internal server error occurred. Retry your request.
ResourceNotFoundException(ResourceNotFoundException)
The specified resource was not found. Verify that the resource exists and that you have permission to access it.
ServiceQuotaExceededException(ServiceQuotaExceededException)
The request would exceed a service quota. Review your service quotas and either delete resources or request a quota increase.
ValidationException(ValidationException)
The input parameters are not valid. Check the parameter values and try again.
ThrottlingException(ThrottlingException)
The request was throttled. Retry your request using exponential backoff.
Unhandled(Unhandled)
Matching Unhandled directly is not forwards compatible. Instead, match using a variable wildcard pattern and check .code():
err if err.code() == Some("SpecificExceptionCode") => { /* handle the error */ }
See ProvideErrorMetadata for what information is available for the error.
An unexpected error occurred (e.g., invalid JSON returned by the service or an unknown error code).
Implementations
Sourceimpl CreateFileSystemError
impl CreateFileSystemError
Sourcepub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
pub fn unhandled(err: impl Into<Box<dyn Error + Send + Sync + 'static>>) -> Self
Creates the CreateFileSystemError::Unhandled variant from any error type.
Sourcepub fn generic(err: ErrorMetadata) -> Self
pub fn generic(err: ErrorMetadata) -> Self
Creates the CreateFileSystemError::Unhandled variant from an ErrorMetadata.
Sourcepub fn meta(&self) -> &ErrorMetadata
pub fn meta(&self) -> &ErrorMetadata
Returns error metadata, which includes the error code, message, request ID, and potentially additional information.
Sourcepub fn is_conflict_exception(&self) -> bool
pub fn is_conflict_exception(&self) -> bool
Returns true if the error kind is CreateFileSystemError::ConflictException.
Sourcepub fn is_internal_server_exception(&self) -> bool
pub fn is_internal_server_exception(&self) -> bool
Returns true if the error kind is CreateFileSystemError::InternalServerException.
Sourcepub fn is_resource_not_found_exception(&self) -> bool
pub fn is_resource_not_found_exception(&self) -> bool
Returns true if the error kind is CreateFileSystemError::ResourceNotFoundException.
Sourcepub fn is_service_quota_exceeded_exception(&self) -> bool
pub fn is_service_quota_exceeded_exception(&self) -> bool
Returns true if the error kind is CreateFileSystemError::ServiceQuotaExceededException.
Sourcepub fn is_validation_exception(&self) -> bool
pub fn is_validation_exception(&self) -> bool
Returns true if the error kind is CreateFileSystemError::ValidationException.
Sourcepub fn is_throttling_exception(&self) -> bool
pub fn is_throttling_exception(&self) -> bool
Returns true if the error kind is CreateFileSystemError::ThrottlingException.